###################################################
### chunk number 1: preliminaries
###################################################
library("zoo")


###################################################
### chunk number 2: duplicates1
###################################################
z <- suppressWarnings(zoo(1:8, c(1, 2, 2, 2, 3, 4, 5, 5)))
z


###################################################
### chunk number 3: duplicates2
###################################################
aggregate(z, force, mean)


###################################################
### chunk number 4: duplicates3
###################################################
aggregate(z, force, tail, 1)


###################################################
### chunk number 5: duplicates4
###################################################
time(z) <- na.approx(ifelse(duplicated(time(z)), NA, time(z)), na.rm = FALSE)


###################################################
### chunk number 6: duplicates5
###################################################
z[!is.na(time(z))]


###################################################
### chunk number 7: log-plot
###################################################
z <- zoo(1:100)
plot(z, log = "y", panel = function(..., log) lines(...))


###################################################
### chunk number 9: factor1
###################################################
DF <- data.frame(time = 1:4, x = 1:4, f = factor(letters[c(1, 1, 2, 2)]))
zx <- zoo(DF$x, DF$time)
zf <- zoo(DF$f, DF$time)


###################################################
### chunk number 10: factor2
###################################################
DF2 <- data.frame(x = zx, f = zf)


###################################################
### chunk number 11: factor3
###################################################
z <- zoo(data.matrix(DF[-1]), DF$time)


###################################################
### chunk number 12: lags
###################################################
z <- zoo(11:15, as.Date("2008-01-01") + c(-4, 1, 2, 3, 6))
zr <- as.zooreg(z)

lag(z)
lag(zr)

diff(log(z))
diff(log(zr))


###################################################
### chunk number 13: subtract-monthly-means
###################################################
set.seed(123)
z <- zoo(rnorm(100), as.Date("2007-01-01") + seq(0, by = 10, length = 100))
z.demean1 <- z - ave(z, as.yearmon(time(z)))


###################################################
### chunk number 14: subtract-monthly-means2
###################################################
z.demean2 <- z - ave(z, format(time(z), "%m"))


###################################################
### chunk number 15: yearmon2
###################################################
# as.yearmon2 generic and as.yearmon2.Date method
as.yearmon2 <- function(x, ...) UseMethod("as.yearmon2")
as.yearmon2.Date <- function(x, ...) {
  y <- as.yearmon(with(as.POSIXlt(x, tz = "GMT"), 1900 + year + mon/12))
  names(y) <- x
  structure(y, class = c("yearmon2", class(y)))
}


###################################################
### chunk number 16: yearmon2-inverse
###################################################
as.Date.yearmon2 <- function(x, frac = 0, ...) {
     if (!is.null(names(x))) return(as.Date(names(x)))
     x <- unclass(x)
     year <- floor(x + .001)
     month <- floor(12 * (x - year) + 1 + .5 + .001)
     dd.start <- as.Date(paste(year, month, 1, sep = "-")) 
     dd.end <- dd.start + 32 - as.numeric(format(dd.start + 32, "%d"))
     as.Date((1-frac) * as.numeric(dd.start) + frac * as.numeric(dd.end), origin = "1970-01-01")
}


###################################################
### chunk number 17: yearmon2-example
###################################################
dd <- seq(as.Date("2000-01-01"), length = 5, by = 32)
z <- zoo(1:5, as.yearmon2(dd))
z
aggregate(z, as.Date, force) 


###################################################
### chunk number 18: single-panel
###################################################
z <- zoo(0:500, as.Date(0:500))
plot(z, xaxt = "n")
tt <- time(z)
m <- unique(as.Date(as.yearmon(tt)))
jan <- format(m, "%m") == "01"
mlab <- substr(months(m[!jan]), 1, 1)
Axis(side = 1, at = m[!jan], labels = mlab, tcl = -0.3, cex.axis = 0.7)
Axis(side = 1, at = m[jan], labels = format(m[jan], "%y"), tcl = -0.7)
Axis(side = 1, at = unique(as.Date(as.yearqtr(tt))), labels = FALSE)


###################################################
### chunk number 19: multiplesingleplot
###################################################
z3 <- cbind(z1 = z, z2 = 2*z, z3 = 3*z)
opar <- par(mfrow = c(2, 2))
tt <- time(z)
m <- unique(as.Date(as.yearmon(tt)))
jan <- format(m, "%m") == "01"
mlab <- substr(months(m[!jan]), 1, 1)
for(i in 1:ncol(z3)) {
    plot(z3[,i], xaxt = "n", ylab = colnames(z3)[i], ylim = range(z3))
    Axis(side = 1, at = m[!jan], labels = mlab, tcl = -0.3, cex.axis = 0.7)
    Axis(side = 1, at = m[jan], labels = format(m[jan], "%y"), tcl = -0.7)
    Axis(side = 1, at = unique(as.Date(as.yearqtr(tt))), labels = FALSE)
}
par(opar)


###################################################
### chunk number 20: multipanelplot
###################################################
plot(z3, screen = 1:3, xaxt = "n", nc = 2, ylim = range(z3),
  panel = function(...) {
   lines(...)
   panel.number <- parent.frame()$panel.number
   nser <- parent.frame()$nser
   # place axis on bottom panel of each column only
   if (panel.number %% 2 == 0 || panel.number == nser) { 
         tt <- list(...)[[1]]
         m <- unique(as.Date(as.yearmon(tt)))
         jan <- format(m, "%m") == "01"
         mlab <- substr(months(m[!jan]), 1, 1)
         Axis(side = 1, at = m[!jan], labels = mlab, tcl = -0.3, cex.axis = 0.7)
         Axis(side = 1, at = m[jan], labels = format(m[jan], "%y"), tcl = -0.7)
         Axis(side = 1, at = unique(as.Date(as.yearqtr(tt))), labels = FALSE)
    }
})


###################################################
### chunk number 21: plot-with-na
###################################################
z <- zoo(c(1, NA, 2, NA, 3))
plot(z)


###################################################
### chunk number 22: plot-with-na1
###################################################
plot(z, type = "p") 


###################################################
### chunk number 23: plot-with-na2
###################################################
plot(na.omit(z))


###################################################
### chunk number 24: plot-with-na3
###################################################
plot(na.approx(z))


###################################################
### chunk number 25: plot-with-na4
###################################################
plot(z, type = "p")
lines(na.omit(z))


###################################################
### chunk number 26: Rmetrics
###################################################
library("fCalendar")
dts <- c("1989-09-28", "2001-01-15", "2004-08-30", "1990-02-09")
tms <- c(  "23:12:55",   "10:34:02",   "08:30:00",   "11:18:23")
td <- timeDate(paste(dts, tms), format = "%Y-%m-%d %H:%M:%S")

library("zoo")
z <- zoo(1:4, td)
zz <- merge(z, lag(z))
plot(zz)

library("fSeries")
zz
as.timeSeries(zz)
as.zoo(as.timeSeries(zz))


